==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_6_2.tar.xz: opt/mae3xx/app/AppServer/Handlers/Config.py <==
# -*- coding: utf-8 -*-
import os
import glob
import shutil
from Handlers import BaseHandler

#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Config(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):

		self.name = 'Config'
		self.overlay = '/rw.tmpfs/.overlay/overlays_*'
		self.config = '/rw.tmpfs/.overlay/overlays_etc.tar.xz'
		self.delete = '/tmp/delete_overlay'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):
		
		return self.readConfig()
		
	#=======================================================
	# 
	#=======================================================
	def Post(self, request):

		status = 400
		file_name = request.get_header('X-File')
		if file_name:
			status = self.saveConfig(file_name)

		return status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		return self.removeOverlay()

	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		status = 503
		config = ''
		try:
			res = self.call('overlaycfg -s etc', shell=True)
			if not res:
				config = open(self.config, 'br').read()
				status = 200
		except Exception as e:
			self.log('read config failed. %s' % e)
			
		return config, status

	#=======================================================
	# 
	#=======================================================
	def saveConfig(self, file_name):

		status = 200
		try:
			res = self.call('tar Jxvf %s -C /' % file_name, shell=True)
			if res:
				status = 400
		except Exception as e:
			self.log('save config failed. %s' % e)
			status = 503

		return status

	#=======================================================
	# 
	#=======================================================
	def removeOverlay(self ):

		status = 200
		files = glob.glob(self.overlay)
		try:
			for file in files:
				os.remove(file)
			fd = open(self.delete,'w')
			fd.close()

		except Exception as e:
			self.log('remove config failed. %s' % e)
			status = 503

		return status

==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_6_8.tar.xz: opt/mae3xx/app/AppServer/Handlers/Config.py <==
# -*- coding: utf-8 -*-
import os
import glob
import shutil
from Handlers import BaseHandler

#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Config(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):

		self.name = 'Config'
		self.overlay = '/rw.tmpfs/.overlay/overlays_*'
		self.config = '/rw.tmpfs/.overlay/overlays_etc.tar.xz'
		self.delete = '/tmp/delete_overlay'
		self.update = '/tmp/update_etc'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):
		
		return self.readConfig()
		
	#=======================================================
	# 
	#=======================================================
	def Post(self, request):

		status = 400
		file_name = request.get_header('X-File')
		if file_name:
			status = self.saveConfig(file_name)

		return status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		return self.removeOverlay()

	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		status = 503
		config = ''
		try:
			res = self.call('overlaycfg -s etc', shell=True)
			if not res:
				config = open(self.config, 'br').read()
				status = 200
		except Exception as e:
			self.log('read config failed. %s' % e)
			
		return config, status

	#=======================================================
	# 
	#=======================================================
	def saveConfig(self, file_name):

		status = 200
		try:
			res = self.call('cp %s %s' % (file_name,self.config), shell=True)
			if res:
				status = 400
			fd = open(self.update,'w')
			fd.close()
			if os.path.exists(self.delete):
				os.remove(self.delete)
		except Exception as e:
			self.log('save config failed. %s' % e)
			status = 503

		return status

	#=======================================================
	# 
	#=======================================================
	def removeOverlay(self ):

		status = 200
		files = glob.glob(self.overlay)
		try:
			for file in files:
				os.remove(file)
			fd = open(self.delete,'w')
			fd.close()
			if os.path.exists(self.update):
				os.remove(self.update)
				
			

		except Exception as e:
			self.log('remove config failed. %s' % e)
			status = 503

		return status
